@@ -33,16 +33,11 @@ function getCsrfToken(){
     if (call.stack.length) {
       let s = call.stack;
       call.stack = [];
-      var headers = {
-        "Content-Type": "application/json;charset=UTF-8",
-        "X-CSRFToken": getCsrfToken()
-      }
-      if(document.location.host === 'localhost:3000' &&
-      localStorage.getItem('Authorization')){
-        headers['Authorization'] = localStorage.getItem('Authorization')
-      }
       fetch("pathToEndpoint", {
-        "headers": headers,
+        "headers": {
+          "Content-Type": "application/json;charset=UTF-8",
+          "X-CSRFToken": getCsrfToken()
+        },
         "method": "POST",
         "credentials": "include",
         "body": JSON.stringify(s)
@@ -53,9 +48,6 @@ function getCsrfToken(){
     }
   },
   resolve: async function (callStack, serverResponse) {
-    if('Authorization' in serverResponse.headers){
-      localStorage.setItem('Authorization', serverResponse.headers['Authorization']);
-    }
     serverResponse = await serverResponse.json()
     serverResponse.forEach((element, i) => {
       if("returned" in element){
